import * as Utils from "../../utils";
const createFormatSchemaToTypeNode = (factory, target) => {
    const typeNodes = target.output.type.map(value => {
        return factory.TypeReferenceNode.create({
            name: value,
        });
    });
    if (target.output.multiType === "allOf") {
        return factory.IntersectionTypeNode.create({
            typeNodes: typeNodes,
        });
    }
    return factory.UnionTypeNode.create({
        typeNodes: typeNodes,
    });
};
/**
 * ユーザーが利用できる各種変換オプション
 */
export const create = (factory, options) => {
    const convertReservedWord = (word) => {
        if (["import", "export"].includes(word)) {
            return word + "_";
        }
        return word;
    };
    const convertString = (text) => {
        if (Utils.isAvailableVariableName(text)) {
            return text;
        }
        return text.replace(/-/g, "$").replace(/\//g, "$");
    };
    const convertOperationId = (text) => {
        return convertString(text).replace(/\./g, "$");
    };
    return {
        escapeOperationIdText: (operationId) => {
            return convertOperationId(operationId);
        },
        escapeDeclarationText: (text) => {
            // console.log(`escapeDeclarationText: ${text}` + `-> ${convertReservedWord(convertString(text).replace(/\./g, "$"))}`.padStart(100, " "));
            return convertReservedWord(convertString(text).replace(/\./g, "$"));
        },
        escapeReferenceDeclarationText: (text) => {
            // console.log(`escapeDeclarationText3: ${text}` + `-> ${convertReservedWord(convertString(text))}`.padStart(100, " "));
            return convertReservedWord(convertString(text));
        },
        escapePropertySignatureName: (text) => {
            return Utils.escapeText(text);
        },
        escapeTypeReferenceNodeName: (text) => {
            return convertString(text);
        },
        generateResponseName: (operationId, statusCode) => {
            return Utils.responseName(convertOperationId(operationId), statusCode);
        },
        generateArgumentParamsTypeDeclaration: (operationId) => {
            return Utils.argumentParamsTypeDeclaration(convertOperationId(operationId));
        },
        generateRequestContentTypeName: (operationId) => {
            return Utils.requestContentType(convertOperationId(operationId));
        },
        generateResponseContentTypeName: (operationId) => {
            return Utils.responseContentType(convertOperationId(operationId));
        },
        generateParameterName: (operationId) => {
            return Utils.parameterName(convertOperationId(operationId));
        },
        generateRequestBodyName: (operationId) => {
            return Utils.requestBodyName(convertOperationId(operationId));
        },
        generateFunctionName: (operationId) => {
            return convertOperationId(operationId);
        },
        convertFormatTypeNode: schema => {
            const formatConversions = options === null || options === void 0 ? void 0 : options.formatConversions;
            if (!formatConversions || formatConversions.length === 0) {
                return;
            }
            if (typeof schema === "boolean") {
                return;
            }
            if (!schema.format) {
                return;
            }
            const target = formatConversions.find(formatConvertion => formatConvertion.selector.format === schema.format);
            if (!target) {
                return;
            }
            return createFormatSchemaToTypeNode(factory, target);
        },
    };
};
//# sourceMappingURL=ConverterContext.js.map